==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/TopologicalOrderer.h <==
// public class soot.jimple.toolkits.callgraph.TopologicalOrderer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5b27204f64a0c091 soot_jimple_toolkits_callgraph_TopologicalOrderer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_TopologicalOrderer_H_
#define _JC_soot_jimple_toolkits_callgraph_TopologicalOrderer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_util_NumberedSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_refs	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$refs	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$nonrefs	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vmethods	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtable	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtype	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method$_init$df901ac5be0f618e(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method$dfsVisit$8ee3c35c31aa43d8(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *, struct _jc_soot_SootMethod$object *);
extern void _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method$go$8f1230f920563986(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method$order$3974a3a17bd84ee3(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method_info$dfsVisit$8ee3c35c31aa43d8;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method_info$go$8f1230f920563986;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method_info$order$3974a3a17bd84ee3;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vmethods {
	void	(*dfsVisit$8ee3c35c31aa43d8)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *, struct _jc_soot_SootMethod$object *);
	void	(*go$8f1230f920563986)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *);
	struct _jc_object	*(*order$3974a3a17bd84ee3)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vmethods	soot_jimple_toolkits_callgraph_TopologicalOrderer;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
	struct _jc_object	*order;
	struct _jc_soot_util_NumberedSet$object	*visited;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$refs {
    _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_refs	soot_jimple_toolkits_callgraph_TopologicalOrderer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_nonrefs	soot_jimple_toolkits_callgraph_TopologicalOrderer;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object {
	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtype _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_TopologicalOrderer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_TopologicalOrderer_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/TopologicalOrderer.h <==
// public class soot.jimple.toolkits.callgraph.TopologicalOrderer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5b27204f64a0c091 soot_jimple_toolkits_callgraph_TopologicalOrderer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_TopologicalOrderer_H_
#define _JC_soot_jimple_toolkits_callgraph_TopologicalOrderer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_util_NumberedSet$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_refs	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$refs	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$nonrefs	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vmethods	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtable	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtype	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method$_init$df901ac5be0f618e(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method$dfsVisit$8ee3c35c31aa43d8(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method$go$8f1230f920563986(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method$order$3974a3a17bd84ee3(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method_info$dfsVisit$8ee3c35c31aa43d8;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method_info$go$8f1230f920563986;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$method_info$order$3974a3a17bd84ee3;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vmethods {
	void	(*dfsVisit$8ee3c35c31aa43d8)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
	void	(*go$8f1230f920563986)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*order$3974a3a17bd84ee3)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vmethods	soot_jimple_toolkits_callgraph_TopologicalOrderer;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
	struct _jc_object	*order;
	struct _jc_soot_util_NumberedSet$object	*visited;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$refs {
    _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_refs	soot_jimple_toolkits_callgraph_TopologicalOrderer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$sub_nonrefs	soot_jimple_toolkits_callgraph_TopologicalOrderer;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$object {
	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$vtype _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_TopologicalOrderer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_TopologicalOrderer$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_TopologicalOrderer_H_ */
